@@ -74,6 +74,9 @@ class Library {
 		if (isset($this->group_id)) {
 			$query .= "l.group_id=" . $this->group_id . " AND ";
 		}
+		else {
+			$query .= "l.group_id is NULL AND ";
+		}
 		
 		$query .="1=1 order by l.library_page_name";
 		
@@ -158,11 +161,11 @@ class Library {
 			;
 		}
 		
-		if (isset($this->user_id)) { // group list
+		if (isset($this->user_id)) {
 			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
 		
-		if (isset($this->group_id)) {
+		if (isset($this->group_id)) { // group list
 			$query .= "l.group_id=" . $this->group_id . " AND ";
 		}
 		
@@ -371,7 +374,7 @@ class Library {
 		if (!empty($pagename)) {
 			$query = "
 				SELECT l.library_id, l.library_title, l.library_create_datetime, l.user_id,
-				p.profile_nic, l.group_id 
+				p.profile_nic, l.group_id, l.library_page_name 
 				FROM " . $this->db->prefix . "_library l
 				LEFT JOIN " . $this->db->prefix . "_user_profile p ON l.user_id=p.user_id
 				WHERE
@@ -555,10 +558,6 @@ class Library {
 			else {
 				$data['library_default'] = "null";
 			}
-
-			if (!empty($data['page'])) {
-			    $data['library_page_name'] = $data['page'];
-			}
 			
 			$rec = array();
 			$rec['library_title'] = $data['library_title'];
